import React, { useEffect, useRef } from 'react';
import { motion } from 'framer-motion';
import { useNavigate } from 'react-router-dom';
import AnimatedNodes from '@/components/AnimatedNodes';
import { useLanguage } from '@/context/LanguageContext';
import LazyImage from '@/components/LazyImage';
import { animationController } from '@/lib/animation';

const HeroSection: React.FC = () => {
  const navigate = useNavigate();
  const { t, language } = useLanguage();
  const sectionRef = useRef<HTMLElement>(null);

  const handleContactClick = () => {
    navigate('/contact');
  };

  useEffect(() => {
    const preloadContact = () => {
      const link = document.createElement('link');
      link.rel = 'modulepreload';
      link.href = '@/components/ContactForm';
      document.head.appendChild(link);
    };

    if (document.readyState !== 'loading') {
      requestIdleCallback(() => {
        animationController.queueAnimation(preloadContact);
      });
    } else {
      document.addEventListener('DOMContentLoaded', () => {
        requestIdleCallback(() => {
          animationController.queueAnimation(preloadContact);
        });
      });
    }
  }, []);

  return (
    <section 
      ref={sectionRef}
      id="inicio" 
      className="relative flex items-center justify-center safari-fix" 
      style={{ 
        minHeight: '100dvh',
        marginTop: '-80px',
        paddingTop: '80px'
      }}
    >
      <AnimatedNodes isHero priority />
      
      <LazyImage
        src="https://images.unsplash.com/photo-1451187580459-43490279c0fa?auto=format&fit=crop&w=1920&q=80"
        alt="AI Technology Background"
        className="absolute inset-0 w-full h-full object-cover opacity-10 safari-fix"
        priority
        sizes="100vw"
      />
      
      <div className="relative z-20 text-center max-w-5xl mx-auto px-6 sm:px-8 py-20 sm:py-32">
        <motion.div
          className="space-y-12 sm:space-y-16"
          initial={{ opacity: 0 }}
          animate={{ opacity: 1 }}
          transition={{ duration: 0.8 }}
        >
          <motion.h1 
            className="text-4xl sm:text-5xl lg:text-6xl font-bold tracking-tight"
            initial={{ opacity: 0, y: -20 }}
            animate={{ opacity: 1, y: 0 }}
            transition={{ duration: 0.5 }}
          >
            {language === 'es' ? (
              <>
                Automatiza y{' '}
                <span className="bg-gradient-to-r from-cyan-400 to-purple-500 text-transparent bg-clip-text animate-pulse">
                  eleva
                </span>{' '}
                tu potencial.
              </>
            ) : (
              <span className="bg-gradient-to-r from-cyan-400 via-purple-500 to-cyan-400 text-transparent bg-clip-text bg-[length:200%_100%] animate-shimmer">
                {t('hero.title')}
              </span>
            )}
          </motion.h1>
          
          <motion.p 
            className="text-xl sm:text-2xl lg:text-3xl text-gray-300 max-w-3xl mx-auto leading-relaxed whitespace-pre-line"
            initial={{ opacity: 0, y: 20 }}
            animate={{ opacity: 1, y: 0 }}
            transition={{ duration: 0.5, delay: 0.2 }}
          >
            {t('hero.subtitle').replace('I.A', 'IA')}
          </motion.p>
          
          <motion.div
            className="flex justify-center pt-8 sm:pt-12 mt-4 sm:mt-0"
            initial={{ opacity: 0, scale: 0.9 }}
            animate={{ opacity: 1, scale: 1 }}
            transition={{ 
              duration: 0.7, 
              delay: 0.4,
              type: "spring",
              stiffness: 200
            }}
          >
            <button 
              onClick={handleContactClick}
              className="bg-[#22d3ee] hover:bg-cyan-400 text-white font-extrabold 
                        text-base sm:text-lg lg:text-xl
                        w-[260px] sm:w-[340px] lg:w-[400px]
                        h-[60px] sm:h-[65px] lg:h-[70px]
                        rounded-xl transition-all duration-300 
                        px-4 sm:px-6
                        hover:shadow-lg hover:shadow-[#22d3ee]/50 
                        transform hover:scale-105
                        flex items-center justify-center
                        whitespace-normal leading-tight
                        relative
                        after:absolute after:inset-0
                        after:rounded-xl after:transition-all after:duration-300
                        after:opacity-0 hover:after:opacity-100
                        after:bg-[#22d3ee] after:blur-xl after:-z-10
                        hover:after:blur-2xl
                        hover:ring-2 hover:ring-cyan-400/50
                        hover:bg-gradient-to-r hover:from-cyan-400 hover:to-cyan-500"
            >
              <strong>{t('hero.cta').replace('I.A', 'IA')}</strong>
            </button>
          </motion.div>
        </motion.div>
      </div>
    </section>
  );
};

export default React.memo(HeroSection);